Function openvet_storage::database::functions::register_all

source ·
pub fn register_all(db: &Connection) -> Result<()>
Register all user-defined functions for a SQLite database [Connection].

This should be called once on any newly created connection, before it is used. Depending on how the schema is built, these functions might not be required for querying the database, allowing you to still access it using the sqlite3 command-line client. But they are required for inserting new values, if any of the methods are part of the schema checks or generated columns.