Struct openvet_storage::database::Database
source · pub struct Database { /* private fields */ }Implementations
sourceimpl Database
impl Database
pub async fn open(path: &Path) -> Result<Self>
pub async fn memory() -> Result<Self>
sourcepub async fn reader(&self) -> Result<Object>
pub async fn reader(&self) -> Result<Object>
Get a handle to a reader.
The readers are managed by the deadpool crate. While the underlying connections can be used for writing, they should only be used to receive data.
pub async fn write<T: 'static + Send, F: FnOnce(&mut Connection) -> T + 'static + Send>( &self, func: F, ) -> Result<T>