Struct openvet_storage::database::InsertRustCrate
source · pub struct InsertRustCrate {
pub name: CrateName,
}Fields
name: CrateNameTrait Implementations
sourceimpl Debug for InsertRustCrate
impl Debug for InsertRustCrate
sourceimpl<'de> Deserialize<'de> for InsertRustCrate
impl<'de> Deserialize<'de> for InsertRustCrate
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Insert for InsertRustCrate
impl Insert for InsertRustCrate
fn table(&self) -> &str
fn insert_or_ignore(&self, connection: &Connection) -> Result<i64, InsertError>
fn insert_or_update(&self, connection: &Connection) -> Result<i64, InsertError>
fn insert(&self, connection: &Connection) -> Result<i64, InsertError>
fn column(&self, name: &str) -> Option<&str>
sourceimpl Ord for InsertRustCrate
impl Ord for InsertRustCrate
sourcefn cmp(&self, other: &InsertRustCrate) -> Ordering
fn cmp(&self, other: &InsertRustCrate) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for InsertRustCrate
impl PartialEq for InsertRustCrate
sourcefn eq(&self, other: &InsertRustCrate) -> bool
fn eq(&self, other: &InsertRustCrate) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for InsertRustCrate
impl PartialOrd for InsertRustCrate
sourcefn partial_cmp(&self, other: &InsertRustCrate) -> Option<Ordering>
fn partial_cmp(&self, other: &InsertRustCrate) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for InsertRustCrate
impl Serialize for InsertRustCrate
impl Eq for InsertRustCrate
impl StructuralPartialEq for InsertRustCrate