Function openvet_storage::database::functions::register_validation_functions
source · pub fn register_validation_functions() -> Result<()>Expand description
Register all built-in validation functions.
This function should be called once at startup, before interacting with the database. Validation functions can be registered (and overridden) at runtime, but this is not recommended because it may produce unexpected results.